gnm: The MCMC Jagger 
====================

**Rock and Rolling awesome Python package for affine-invariant MCMC sampling**

gnm is a well tested Python implementation of the affine-invariant sampler for Markov chain Monte Carlo (MCMC) that uses the Gauss-Newton-Metropolis (GNM) Algorithm. The GNM algorithm is specialized in sampling highly non-linear posterior probability distribution functions of the form exp(-||f(x)||^2/2). 


Pages
-----

home_, github_

.. _home: http://montecarlosampler.com

.. _github: https://github.com/mugurbil/gnm

Attribution
-----------

Goodman_

.. _Goodman: http://www.math.nyu.edu/faculty/goodman/

Copyright
---------

Copyright 2017 `Mehmet Ugurbil`_ and contributors.

.. _Mehmet Ugurbil: http://montecarlosampler.com/memo


License
-------

gnm is a free software made available under the MIT LICENSE.
